pub struct Root {}Trait Implementations
Sourceimpl Build for Root
impl Build for Root
Sourcefn as_any(&self) -> &dyn Any
fn as_any(&self) -> &dyn Any
Returns a reference to the resource as
dyn Any.
Must be implemented for a concrete type as a defualt implementation
suffers from type erasure.Sourcefn equals(&self, other: Rc<RefCell<dyn Build>>) -> bool
fn equals(&self, other: Rc<RefCell<dyn Build>>) -> bool
Returns true if the resource is equal to the other resource.
Used to determine if the resource has already been registered.
Generally this should return false unless
other can be downcast to
Self.Auto Trait Implementations
impl Freeze for Root
impl RefUnwindSafe for Root
impl Send for Root
impl Sync for Root
impl Unpin for Root
impl UnwindSafe for Root